@@ -194,6 +194,24 @@ class TcSoaBasics:
     def bool2property_str(cls, val: bool) -> str:
         return '1' if val else '0'
 
+    @classmethod
+    def setMultiPropString(cls, bo: BusinessObject, prop2val_map: Dict[str, str]):
+        DataManagementService.setProperties2(
+            info=[
+                PropInfo(
+                    object=bo,
+                    vecNameVal=[
+                        NameValueStruct1(
+                            name=prop_name,
+                            values=[prop_val]
+                        )
+                        for prop_name, prop_val in prop2val_map.items()
+                    ]
+                )
+            ],
+            options=[],
+        )
+
     @classmethod
     def setPropString(cls, bo: BusinessObject, prop_name: str, prop_val: str):
         DataManagementService.setProperties2(
