@@ -1,7 +1,7 @@
 from tcsoa.gen.Diagramming._2014_06.services import DNDManagementService as imp0
 from tcsoa.gen.Diagramming._2011_06.services import DiagramManagementService as imp1
 from tcsoa.gen.Diagramming._2012_09.services import DiagramManagementService as imp2
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DNDManagementService(TcService):
