@@ -3,7 +3,7 @@ from tcsoa.gen.Internal_BusinessModeler._2010_09.services import DataModelManage
 from tcsoa.gen.Internal_BusinessModeler._2013_05.services import DynamicLOVQueryService as imp2
 from tcsoa.gen.Internal_BusinessModeler._2007_01.services import DataModelManagementService as imp3
 from tcsoa.gen.Internal_BusinessModeler._2011_06.services import DataModelManagementService as imp4
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DataModelManagementService(TcService):
