@@ -5,7 +5,7 @@ from tcsoa.gen.Internal_Cad._2013_05.services import DataManagementService as im
 from tcsoa.gen.Internal_Cad._2008_06.services import DataManagementService as imp4
 from tcsoa.gen.Internal_Cad._2008_05.services import DataManagementService as imp5
 from tcsoa.gen.Internal_Cad._2010_04.services import DataManagementService as imp6
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DataManagementService(TcService):
