@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_Gdis._2006_03.services import ReportingService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ReportingService(TcService):
