@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.ProjectManagementAw._2019_12.ScheduleManagementAw import ManageProgramViewResponse, ProgramViewInfo
-from tcsoa.utils import TcService
+from tcsoa.gen.Internal.ProjectManagementAw._2019_12.ScheduleManagementAw import ProgramViewInfo, ManageProgramViewResponse
+from tcsoa.base import TcService
 
 
 class ScheduleManagementAwService(TcService):
